@@ -214,13 +214,10 @@ main (int argc, char *argv[])
 
   g_test_init (&argc, &argv, NULL);
 
-  /* Preserve DISPLAY for wlroots x11 backend */
-  cfg = phosh_test_full_shell_fixture_cfg_new (g_getenv ("DISPLAY"), "phosh-calls-manager");
+  cfg = phosh_test_full_shell_fixture_cfg_new (NULL, "phosh-calls-manager");
 
-  g_test_add ("/phosh/dbus/calls-manager/present", PhoshTestFullShellFixture, cfg,
-              phosh_test_full_shell_setup, test_phosh_calls_present, phosh_test_full_shell_teardown);
-  g_test_add ("/phosh/dbus/calls-manager/incoming", PhoshTestFullShellFixture, cfg,
-              phosh_test_full_shell_setup, test_phosh_calls_incoming, phosh_test_full_shell_teardown);
+  PHOSH_FULL_SHELL_TEST_ADD ("/phosh/dbus/calls-manager/present",cfg, test_phosh_calls_present);
+  PHOSH_FULL_SHELL_TEST_ADD ("/phosh/dbus/calls-manager/incoming", cfg, test_phosh_calls_incoming);
 
   return g_test_run ();
 }
